@@ -8,8 +8,10 @@ import click
         )
 @click.option(
         '-i',
-        '--inputimage',
+        '--inputfile',
         type=click.Path(),
+        default="./main.png",
+        show_default=True,
         help="Input file"
         )
 @click.option(
@@ -17,6 +19,7 @@ import click
         '--outputfile',
         type=click.Path(),
         default="./pixelated.png",
+        show_default=True,
         help="Output file"
         )
 @click.option(
